==> php82-nextcloud-26.0.5.tgz: share/nextcloud/apps/serverinfo/l10n/ja.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU情報が利用できません",
    "Load average: {cpu} (last minute)" : "平均ロード: {cpu} (最終11分)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: 合計: {memTotalBytes}/現在の使用率: {memUsageBytes}",
    "RAM info not available" : "RAM情報が利用不可",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "スワップ: 合計: {swapTotalBytes}/現在の使用率: {swapUsageBytes}",
    "SWAP info not available" : "SWAP情報なし",
    "Not supported!" : "対応していません！",
    "Press ⌘-C to copy." : "⌘-C でコピーします。",
    "Press Ctrl-C to copy." : "Ctrl-Cを押してコピーします。",
    "System" : "システム",
    "Monitoring" : "モニタリング",
    "Monitoring app with useful server information" : "有用なサーバー情報でアプリケーションを監視する",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "CPU負荷、メモリ使用量、ディスク使用量、ユーザー数などの役に立つサーバー情報を提供します。",
    "Operating System:" : "OS:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "不明なプロセッサー",
    "Memory:" : "メモリ:",
    "Server time:" : "サーバーの時間:",
    "Uptime:" : "稼働時間：",
    "Temperature" : "温度",
    "Load" : "負荷",
    "Memory" : "メモリ",
    "Disk" : "ディスク",
    "Mount:" : "マウント:",
    "Filesystem:" : "ファイルシステム:",
    "Size:" : "サイズ:",
    "Available:" : "利用可能:",
    "Used:" : "使用中:",
    "You will get a notification once one of your disks is nearly full." : "いずれかのディスクがいっぱいになると通知を受け取ります。",
    "Files:" : "ファイル数:",
    "Storages:" : "ストレージ：",
    "Free Space:" : "空き容量：",
    "Network" : "ネットワーク",
    "Hostname:" : "ホスト名:",
    "DNS:" : "DNS:",
    "Gateway:" : "ゲートウェイ:",
    "Status:" : "ステータス:",
    "Speed:" : "速度:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "アクティブユーザー数",
    "Total users:" : "総ユーザー数：",
    "Shares" : "共有数",
    "Users:" : "ユーザー数:",
    "PHP" : "PHP",
    "Version:" : "バージョン:",
    "Memory limit:" : "メモリ制限:",
    "Max execution time:" : "最大実行時間:",
    "Upload max size:" : "最大アップロードサイズ:",
    "Extensions:" : "拡張:",
    "Unable to list extensions" : "拡張リストを読み込めません",
    "Database" : "データベース",
    "Type:" : "タイプ:",
    "External monitoring tool" : "外部モニタリングツール",
    "You can connect an external monitoring tool by using this end point:" : "このエンドポイントを利用して外部モニタリングツールに接続することが可能です：",
    "Copy" : "コピー",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "URLの最後に \"?format=json\" を追加すると、JSONの結果が得られます。",
    "To use an access token, please generate one then set it using the following command:" : "アクセストークンを使用するには、アクセストークンを生成し、以下のコマンドで設定してください。",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "次に、上記のURLをクエリするときに、\"NC-Token\" ヘッダーでトークンを渡します。"
},
"nplurals=1; plural=0;");

==> php82-nextcloud-28.0.2.tgz: share/nextcloud/apps/serverinfo/l10n/ja.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU情報が利用できません",
    "Load average: {cpu} (last minute)" : "平均ロード: {cpu} (最終11分)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: 合計: {memTotalBytes}/現在の使用率: {memUsageBytes}",
    "RAM info not available" : "RAM情報が利用不可",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "スワップ: 合計: {swapTotalBytes}/現在の使用率: {swapUsageBytes}",
    "SWAP info not available" : "SWAP情報なし",
    "Copied!" : "コピー完了",
    "Not supported!" : "対応していません！",
    "Press ⌘-C to copy." : "⌘-C でコピーします。",
    "Press Ctrl-C to copy." : "Ctrl-Cを押してコピーします。",
    "System" : "システム",
    "Monitoring" : "モニタリング",
    "Monitoring app with useful server information" : "有用なサーバー情報でアプリケーションを監視する",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "CPU負荷、メモリ使用量、ディスク使用量、ユーザー数などの役に立つサーバー情報を提供します。",
    "Operating System:" : "OS:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "不明なプロセッサー",
    "Memory:" : "メモリ:",
    "Server time:" : "サーバーの時間:",
    "Uptime:" : "稼働時間：",
    "Temperature" : "温度",
    "Load" : "負荷",
    "Memory" : "メモリ",
    "Disk" : "ディスク",
    "Mount:" : "マウント:",
    "Filesystem:" : "ファイルシステム:",
    "Size:" : "サイズ:",
    "Available:" : "利用可能:",
    "Used:" : "使用中:",
    "Files:" : "ファイル数:",
    "Storages:" : "ストレージ：",
    "Free Space:" : "空き容量：",
    "Network" : "ネットワーク",
    "Hostname:" : "ホスト名:",
    "DNS:" : "DNS:",
    "Gateway:" : "ゲートウェイ:",
    "Status:" : "ステータス:",
    "Speed:" : "速度:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "アクティブユーザー数",
    "Total users:" : "総ユーザー数：",
    "Shares" : "共有数",
    "Users:" : "ユーザー数:",
    "PHP" : "PHP",
    "Version:" : "バージョン:",
    "Memory limit:" : "メモリ制限:",
    "Max execution time:" : "最大実行時間:",
    "Upload max size:" : "最大アップロードサイズ:",
    "Extensions:" : "拡張:",
    "Unable to list extensions" : "拡張リストを読み込めません",
    "Database" : "データベース",
    "Type:" : "タイプ:",
    "External monitoring tool" : "外部モニタリングツール",
    "Copy" : "コピー",
    "To use an access token, please generate one then set it using the following command:" : "アクセストークンを使用するには、アクセストークンを生成し、以下のコマンドで設定してください。",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "次に、上記のURLをクエリするときに、\"NC-Token\" ヘッダーでトークンを渡します。"
},
"nplurals=1; plural=0;");
